searchData={"content_type":"text/markdown","items":[{"doc":"TwMerge adds efficient class joining and merging of TailwindCSS classes to Elixir.\n\nTailwindCSS class names are composable and allow specifying an infinite amount of different styles. Most components allow overriding class\nnames, like as passing `class` attribute that then gets merged with the existing styles. This can result in class lists such as\n`text-white bg-red-500 bg-blue-300` where `text-white bg-red-500` is the preset style, and `bg-blue-300` is the override for that one\nspecific button that needs to look slightly different.\nStyles based on class are applied according to the order _they are defined at in the stylesheet_. In this example, because TailwindCSS\norders color definitions alphabetically, the override does not work. `blue` is defined before `red`, so the `bg-red-500` class takes\nprecedence since it was defined later.\n\nIn order to still allow overriding styles, TwMerge traverses the entire class list, creates a list of all classes and which\nconflicting groups of styles exist in them and gives precedence to the ones that were defined last _in the class list_, which, unlike the\nstylesheet, is in control of the user.","ref":"TwMerge.html","title":"TwMerge","type":"module"},{"doc":"```elixir\niex> merge(\"text-white bg-red-500 bg-blue-300\")\n\"text-white bg-blue-300\"\n\niex> merge([\"px-2 py-1 bg-red hover:bg-dark-red\", \"p-3 bg-[#B91C1C]\"])\n\"hover:bg-dark-red p-3 bg-[#B91C1C]\"\n```","ref":"TwMerge.html#module-example","title":"Example - TwMerge","type":"module"},{"doc":"TwMerge does not currently support full theme configuration - that's on the roadmap!\n\nThe limited configuration at the moment is adding Tailwind's `prefix` option.\n\n```elixir\nconfig :tw_merge,\n  prefix: \"tw-\"\n```","ref":"TwMerge.html#module-configuration","title":"Configuration - TwMerge","type":"module"},{"doc":"Joins a list of classes.","ref":"TwMerge.html#join/1","title":"TwMerge.join/1","type":"function"},{"doc":"Joins and merges a list of classes.\n\nPasses the input to `join/1` before merging.","ref":"TwMerge.html#merge/2","title":"TwMerge.merge/2","type":"function"},{"doc":"# TwMerge\n\nUtilities to merge TailwindCss classes.\n\nThis library is extracted from [Turboprop](https://github.com/leuchtturm-dev/turboprop/)","ref":"readme.html","title":"TwMerge","type":"extras"},{"doc":"- `tails` has been soft deprecated because it has some issues which is not fixed. As discussed in [Elixir Forum](https://elixirforum.com/t/turboprop-toolkit-to-create-accessible-component-libraries/64228/3?u=bluzky)\n- `turboprop` is archived too, so I create another repository and extract code to merge TailwindCss only.","ref":"readme.html#why-another-fork","title":"Why another fork? - TwMerge","type":"extras"},{"doc":"1. Adding `tw_merge` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tw_merge, \"~> 0.1.0\"}\n  ]\nend\n```\n\n\n2. Add `TwMerge.Cache` to children list in your `application.ex`\n\n```elixir\n    children = [\n      ....\n      TwMerge.Cache,\n    ]\n```","ref":"readme.html#installation","title":"Installation - TwMerge","type":"extras"}],"producer":{"name":"ex_doc","version":"0.35.0"},"proglang":"elixir"}